.. _project: https://gitlab.com/signalytics/signalyzer
.. _issue: https://gitlab.com/signalytics/signalyzer/-/issues

Issue Reports
=============

Filing an Issue Report
----------------------

If you encounter a bug, misfeature, or missing feature, please file an `issue`_
report. We also appreciate reports of incomplete or misleading information in the
documentation; file those against the "documentation" category.

Don't hesitate to file an `issue`_ report, even if you think I may know about it
already, or aren't sure of the details. Just give us as much information as you
have, and if it's already fixed or has already been discussed, I'll add a note
to that effect in the report.

The `issue`_ tracker should definitely be used for feature requests, it's not
only for bugs. We track the development in it, so it's the way to be sure the
developers won't forget about an issue.

Submitting Patches
------------------

If you develop a bug fix or enhancement, please file that in the `issue`_ tracker
as well. The `issue`_ tracker allows you to attach files. All patches must be
offered under the same terms of the license used by the `project`_, so be sure
you are authorized to give us the patch under those terms.

If you want to discuss your patch before or after developing it, mail to
jochen_privat@gmx.com. But be sure to file the `issue`_ report as well;
if the patch is only on the list and not in the `issue`_ tracker, it's likely to
slip through the cracks.
